[alsa-cvslog] CVS: alsa-utils/aplay aplay.c,1.177,1.178

2004-03-09 Thread Jaroslav Kysela
Update of /cvsroot/alsa/alsa-utils/aplay
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv21804

Modified Files:
aplay.c 
Log Message:
Jeff Law
aplay.c relies upon a GCC extension that has been removed.
Specifically the "cast as lvalue" extension. This patch removes
this dependency.


Index: aplay.c
===
RCS file: /cvsroot/alsa/alsa-utils/aplay/aplay.c,v
retrieving revision 1.177
retrieving revision 1.178
diff -u -r1.177 -r1.178
--- aplay.c 9 Mar 2004 13:18:29 -   1.177
+++ aplay.c 9 Mar 2004 17:43:46 -   1.178
@@ -173,7 +173,7 @@
 "-I, --separate-channels one file for each channel\n"
, command);
fprintf(stderr, "Recognized sample formats are:");
-   for (k = 0; k < SND_PCM_FORMAT_LAST; ++(unsigned long) k) {
+   for (k = 0; k < SND_PCM_FORMAT_LAST; ++k) {
const char *s = snd_pcm_format_name(k);
if (s)
fprintf(stderr, " %s", s);
@@ -588,7 +588,7 @@
return result > 0 ? result : res;
count -= res;
result += res;
-   (char *)buf += res;
+   buf = (char *)buf + res;
}
return result;
 }



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-kernel/usb usbaudio.h,1.23,1.24 usbmixer.c,1.24,1.25 usbmixer_maps.c,1.5,1.6

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-kernel/usb
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv8502

Modified Files:
usbaudio.h usbmixer.c usbmixer_maps.c 
Log Message:
added fix and workaround for the mixer problem on SB Extigy.



Index: usbaudio.h
===
RCS file: /cvsroot/alsa/alsa-kernel/usb/usbaudio.h,v
retrieving revision 1.23
retrieving revision 1.24
diff -u -r1.23 -r1.24
--- usbaudio.h  19 Jan 2004 19:33:46 -  1.23
+++ usbaudio.h  9 Mar 2004 16:57:34 -   1.24
@@ -136,6 +136,8 @@
 
struct list_head midi_list; /* list of midi interfaces */
int next_midi_device;
+
+   unsigned int ignore_ctl_error;  /* for mixer */
 };  
 
 /*

Index: usbmixer.c
===
RCS file: /cvsroot/alsa/alsa-kernel/usb/usbmixer.c,v
retrieving revision 1.24
retrieving revision 1.25
diff -u -r1.24 -r1.25
--- usbmixer.c  26 Sep 2003 14:29:05 -  1.24
+++ usbmixer.c  9 Mar 2004 16:57:36 -   1.25
@@ -667,13 +667,11 @@
for (c = 0; c < MAX_CHANNELS; c++) {
if (cval->cmask & (1 << c)) {
err = get_cur_mix_value(cval, c + 1, &val);
-#ifdef IGNORE_CTL_ERROR
-   if (err < 0) {
-   ucontrol->value.integer.value[0] = cval->min;
-   return 0;
-   }
-#endif
if (err < 0) {
+   if (cval->chip->ignore_ctl_error) {
+   ucontrol->value.integer.value[0] = 
cval->min;
+   return 0;
+   }
snd_printd(KERN_ERR "cannot get current value 
for control %d ch %d: err = %d\n", cval->control, c + 1, err);
return err;
}
@@ -685,13 +683,11 @@
} else {
/* master channel */
err = get_cur_mix_value(cval, 0, &val);
-#ifdef IGNORE_CTL_ERROR
-   if (err < 0) {
-   ucontrol->value.integer.value[0] = cval->min;
-   return 0;
-   }
-#endif
if (err < 0) {
+   if (cval->chip->ignore_ctl_error) {
+   ucontrol->value.integer.value[0] = cval->min;
+   return 0;
+   }
snd_printd(KERN_ERR "cannot get current value for control %d 
master ch: err = %d\n", cval->control, err);
return err;
}
@@ -713,12 +709,11 @@
for (c = 0; c < MAX_CHANNELS; c++) {
if (cval->cmask & (1 << c)) {
err = get_cur_mix_value(cval, c + 1, &oval);
-#ifdef IGNORE_CTL_ERROR
-   if (err < 0)
-   return 0;
-#endif
-   if (err < 0)
+   if (err < 0) {
+   if (cval->chip->ignore_ctl_error)
+   return 0;
return err;
+   }
val = ucontrol->value.integer.value[cnt];
val = get_abs_value(cval, val);
if (oval != val) {
@@ -732,10 +727,8 @@
} else {
/* master channel */
err = get_cur_mix_value(cval, 0, &oval);
-#ifdef IGNORE_CTL_ERROR
-   if (err < 0)
+   if (err < 0 && cval->chip->ignore_ctl_error)
return 0;
-#endif
if (err < 0)
return err;
val = ucontrol->value.integer.value[0];
@@ -1025,12 +1018,10 @@
int err, val;
 
err = get_cur_ctl_value(cval, cval->control << 8, &val);
-#ifdef IGNORE_CTL_ERROR
-   if (err < 0) {
+   if (err < 0 && cval->chip->ignore_ctl_error) {
ucontrol->value.integer.value[0] = cval->min;
return 0;
}
-#endif
if (err < 0)
return err;
val = get_relative_value(cval, val);
@@ -1045,12 +1036,11 @@
int val, oval, err;
 
err = get_cur_ctl_value(cval, cval->control << 8, &oval);
-#ifdef IGNORE_CTL_ERROR
-   if (err < 0)
-   return 0;
-#endif
-   if (err < 0)
+   if (err < 0) {
+   if (cval->chip->ignore_ctl_error)
+   return 0;
return err;
+   }
val = ucontrol->value.integer.value[0];
val = get_abs_value(cval, val);
if (val != oval) {
@@ -1274,14 +1264,13 @@
int val, er

[alsa-cvslog] CVS: alsa-kernel/ppc tumbler.c,1.28,1.29

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-kernel/ppc
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv8660

Modified Files:
tumbler.c 
Log Message:
fixed the info callback of mixer input source (for enum type).



Index: tumbler.c
===
RCS file: /cvsroot/alsa/alsa-kernel/ppc/tumbler.c,v
retrieving revision 1.28
retrieving revision 1.29
diff -u -r1.28 -r1.29
--- tumbler.c   9 Mar 2004 13:21:44 -   1.28
+++ tumbler.c   9 Mar 2004 16:58:22 -   1.29
@@ -695,8 +695,7 @@
};
uinfo->type = SNDRV_CTL_ELEM_TYPE_ENUMERATED;
uinfo->count = 1;
-   uinfo->value.integer.min = 0;
-   uinfo->value.integer.max = 1;
+   uinfo->value.enumerated.items = 2;
if (uinfo->value.enumerated.item > 1)
uinfo->value.enumerated.item = 1;
strcpy(uinfo->value.enumerated.name, texts[uinfo->value.enumerated.item]);



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-kernel/Documentation/DocBook alsa-driver-api.tmpl,1.4,1.5

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-kernel/Documentation/DocBook
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv16163/Documentation/DocBook

Modified Files:
alsa-driver-api.tmpl 
Log Message:
fixed the files to include.




Index: alsa-driver-api.tmpl
===
RCS file: /cvsroot/alsa/alsa-kernel/Documentation/DocBook/alsa-driver-api.tmpl,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- alsa-driver-api.tmpl28 Feb 2003 16:03:58 -  1.4
+++ alsa-driver-api.tmpl9 Mar 2004 13:43:17 -   1.5
@@ -49,7 +49,6 @@
 !Esound/core/memory.c
 !Iinclude/sound/sndmagic.h
 !Esound/core/memalloc.c
-!Esound/core/sgbuf.c
  
   
   PCM API
@@ -71,6 +70,7 @@
  
  AC97 Codec API
 !Esound/pci/ac97/ac97_codec.c
+!Esound/pci/ac97/ac97_pcm.c
  
   
   MIDI API



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-kernel/Documentation/DocBook writing-an-alsa-driver.tmpl,1.23,1.24

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-kernel/Documentation/DocBook
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv16037/Documentation/DocBook

Modified Files:
writing-an-alsa-driver.tmpl 
Log Message:
changed the description of the buffer allocation routines
for the new designed functions.



Index: writing-an-alsa-driver.tmpl
===
RCS file: /cvsroot/alsa/alsa-kernel/Documentation/DocBook/writing-an-alsa-driver.tmpl,v
retrieving revision 1.23
retrieving revision 1.24
diff -u -r1.23 -r1.24
--- writing-an-alsa-driver.tmpl 25 Feb 2004 11:21:41 -  1.23
+++ writing-an-alsa-driver.tmpl 9 Mar 2004 13:42:44 -   1.24
@@ -18,8 +18,8 @@
   
  
 
- Mar. 26, 2003
- 0.3
+ Mar. 6, 2004
+ 0.3.1
 
 
   
@@ -30,7 +30,7 @@
 
 
 
-Copyright (c) 2002, 2003  Takashi Iwai [EMAIL PROTECTED]
+Copyright (c) 2002-2004  Takashi Iwai [EMAIL PROTECTED]
 
 
 
@@ -111,18 +111,18 @@
 
   
 One is the the trees provided as a tarball or via cvs from the
-  ALSA's ftp site, and another is the 2.5 (or later) Linux kernel
+  ALSA's ftp site, and another is the 2.6 (or later) Linux kernel
   tree. To synchronize both, the ALSA driver tree is split to
   two different trees: alsa-kernel and alsa-driver. The former
-  contains purely the source codes for the Linux 2.5 (or later)
-  tree. This tree is designed only for compilation on 2.5 or
+  contains purely the source codes for the Linux 2.6 (or later)
+  tree. This tree is designed only for compilation on 2.6 or
   later environment. The latter, alsa-driver, contains many subtle
   files for compiling the ALSA driver on the outside of Linux
   kernel like configure script, the wrapper functions for older,
   2.2 and 2.4 kernels, to adapt the latest kernel API,
   and additional drivers which are still in development or in
   tests.  The drivers in alsa-driver tree will be moved to
-  alsa-kernel (eventually 2.5 kernel tree) once when they are
+  alsa-kernel (eventually 2.6 kernel tree) once when they are
   finished and confirmed to work fine.
   
 
@@ -346,7 +346,7 @@
 
   oss directory
   
-The OSS/Lite source files are stored here on Linux 2.5 (or
+The OSS/Lite source files are stored here on Linux 2.6 (or
   later) tree. (In the ALSA driver tarball, it's empty, of course :) 
   
 
@@ -1815,7 +1815,7 @@
 
   
 Oh, one thing was forgotten. If you have no exported symbols,
-you need to declare it on 2.2 or 2.4 kernels (on 2.5 kernels
+you need to declare it on 2.2 or 2.4 kernels (on 2.6 kernels
 it's not necessary, though).
 
 
@@ -2075,8 +2075,9 @@
   snd_pcm_set_ops(pcm, SNDRV_PCM_STREAM_CAPTURE,
   &snd_mychip_capture_ops);
   /* pre-allocation of buffers */
-  snd_pcm_lib_preallocate_pci_pages_for_all(chip->pci, pcm,
-64*1024, 64*1024);
+  snd_pcm_lib_preallocate_pages_for_all(pcm, SNDRV_DMA_TYPE_DEV,
+snd_dma_pci_data(chip->pci),
+64*1024, 64*1024);
   return 0;
   }
 ]]>
@@ -2202,8 +2203,9 @@
 
   
 
   
 
@@ -4724,7 +4726,8 @@
 
   
 
   
 
@@ -4734,8 +4737,25 @@
   size to be changed via prealloc proc file.
   The allocator will try to get as the large area as possible
   within the given size. 
-  There are different versions of pre-allocator for different
-  buses.
+  
+
+  
+  The second argument (type) and the third argument (device pointer)
+  are dependent on the bus.
+  In the case of ISA bus, pass snd_dma_isa_data()
+  as the third argument with SNDRV_DMA_TYPE_DEV type.
+  For the continuous buffer unrelated to the bus can be pre-allocated
+  with SNDRV_DMA_TYPE_CONTINUOUS type and the
+  snd_dma_continuous_data(GFP_KERNEL) device pointer,
+  whereh GFP_KERNEL is the kernel allocation flag to
+  use.  For the SBUS, SNDRV_DMA_TYPE_SBUS and
+  snd_dma_sbus_data(sbus_dev) are used instead.
+  For the PCI scatter-gather buffers, use
+  SNDRV_DMA_TYPE_DEV_SG with
+  snd_dma_pci_data(pci)
+  (see the section
+  Non-Contiguous 
Buffers
+  ).
   
 
   
@@ -4942,11 +4962,13 @@
 
   
 For creating the SG-buffer handler, call
-snd_pcm_lib_preallocate_sg_pages() or
-snd_pcm_lib_preallocate_sg_pages_for_all()
+snd_pcm_lib_preallocate_pages() or
+snd_pcm_lib_preallocate_pages_for_all()
+with SNDRV_DMA_TYPE_DEV_SG
in the PCM constructor like other PCI pre-allocator.
-You need to pass the
-pci_dev struct pointer of the chip.
+You n

[alsa-cvslog] CVS: alsa-kernel/ppc tumbler.c,1.27,1.28

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-kernel/ppc
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv11932/ppc

Modified Files:
tumbler.c 
Log Message:
added input source switch to select mic/line-in.



Index: aplay.c
===
RCS file: /cvsroot/alsa/alsa-utils/aplay/aplay.c,v
retrieving revision 1.176
retrieving revision 1.177
diff -u -r1.176 -r1.177
--- aplay.c 28 Nov 2003 10:24:53 -  1.176
+++ aplay.c 9 Mar 2004 13:18:29 -   1.177
@@ -36,6 +36,7 @@
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -46,6 +47,10 @@
 #include "formats.h"
 #include "version.h"
 
+#ifndef LLONG_MAX
+#define LLONG_MAX9223372036854775807LL
+#endif
+
 #define DEFAULT_SPEED  8000
 
 #define FORMAT_DEFAULT -1
@@ -93,7 +98,7 @@
 static snd_output_t *log;
 
 static int fd = -1;
-static off64_t pbrec_count = (size_t)-1, fdcount;
+static off64_t pbrec_count = LLONG_MAX, fdcount;
 static int vocmajor, vocminor;
 
 /* needed prototypes */
@@ -1513,15 +1518,11 @@
 {
off64_t count;
 
-   if (!timelimit && pbrec_count == (size_t)-1) {
-   count = (off64_t)-1;
+   if (timelimit == 0) {
+   count = pbrec_count;
} else {
-   if (timelimit == 0) {
-   count = pbrec_count;
-   } else {
-   count = snd_pcm_format_size(hwparams.format, hwparams.rate * 
hwparams.channels);
-   count *= (off64_t)timelimit;
-   }
+   count = snd_pcm_format_size(hwparams.format, hwparams.rate * 
hwparams.channels);
+   count *= (off64_t)timelimit;
}
return count < pbrec_count ? count : pbrec_count;
 }
@@ -1766,11 +1767,11 @@
 
 /* playing raw data */
 
-void playback_go(int fd, size_t loaded, size_t count, int rtype, char *name)
+void playback_go(int fd, size_t loaded, off64_t count, int rtype, char *name)
 {
int l, r;
-   size_t written = 0;
-   size_t c;
+   off64_t written = 0;
+   off64_t c;
 
header(rtype, name);
set_params();
@@ -1817,9 +1818,10 @@
 
 /* capturing raw data, this proc handels WAVE files and .VOCs (as one block) */
 
-void capture_go(int fd, size_t count, int rtype, char *name)
+void capture_go(int fd, off64_t count, int rtype, char *name)
 {
-   size_t c, cur;
+   size_t c;
+   off64_t cur;
ssize_t r, err;
 
header(rtype, name);
@@ -1854,7 +1856,7 @@
size_t dta;
ssize_t dtawave;
 
-   pbrec_count = (size_t)-1;
+   pbrec_count = LLONG_MAX;
fdcount = 0;
if (!name || !strcmp(name, "-")) {
fd = fileno(stdin);
@@ -1905,7 +1907,7 @@
 
 static void capture(char *name)
 {
-   pbrec_count = (size_t)-1;
+   pbrec_count = LLONG_MAX;
if (!name || !strcmp(name, "-")) {
fd = fileno(stdout);
name = "stdout";
@@ -1929,7 +1931,7 @@
fmt_rec_table[file_type].end(fd);
 }
 
-void playbackv_go(int* fds, unsigned int channels, size_t loaded, size_t count, int 
rtype, char **names)
+void playbackv_go(int* fds, unsigned int channels, size_t loaded, off64_t count, int 
rtype, char **names)
 {
int r;
size_t vsize;
@@ -1979,7 +1981,7 @@
snd_pcm_drain(handle);
 }
 
-void capturev_go(int* fds, unsigned int channels, size_t count, int rtype, char 
**names)
+void capturev_go(int* fds, unsigned int channels, off64_t count, int rtype, char 
**names)
 {
size_t c;
ssize_t r;



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-lib/include/sound ainstr_fm.h,1.1,1.2 ainstr_iw.h,1.1,1.2 ainstr_simple.h,1.1,1.2

2004-03-09 Thread Jaroslav Kysela
Update of /cvsroot/alsa/alsa-lib/include/sound
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv5063

Modified Files:
ainstr_fm.h ainstr_iw.h ainstr_simple.h 
Log Message:
Added workaround for 2.6 kernel, we should probably use C99 types (u_int32_t etc.)

Index: ainstr_fm.h
===
RCS file: /cvsroot/alsa/alsa-lib/include/sound/ainstr_fm.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ainstr_fm.h 9 Oct 2002 13:44:11 -   1.1
+++ ainstr_fm.h 9 Mar 2004 12:46:59 -   1.2
@@ -25,8 +25,10 @@
 #define __SOUND_AINSTR_FM_H
 
 #ifndef __KERNEL__
+#define __KERNEL__
 #include 
 #include 
+#undef __KERNEL__
 #endif
 
 /*

Index: ainstr_iw.h
===
RCS file: /cvsroot/alsa/alsa-lib/include/sound/ainstr_iw.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ainstr_iw.h 9 Oct 2002 13:44:11 -   1.1
+++ ainstr_iw.h 9 Mar 2004 12:47:00 -   1.2
@@ -25,8 +25,10 @@
 #define __SOUND_AINSTR_IW_H
 
 #ifndef __KERNEL__
+#define __KERNEL__
 #include 
 #include 
+#undef __KERNEL__
 #endif
 
 /*

Index: ainstr_simple.h
===
RCS file: /cvsroot/alsa/alsa-lib/include/sound/ainstr_simple.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ainstr_simple.h 9 Oct 2002 13:44:11 -   1.1
+++ ainstr_simple.h 9 Mar 2004 12:47:00 -   1.2
@@ -25,8 +25,10 @@
 #define __SOUND_AINSTR_SIMPLE_H
 
 #ifndef __KERNEL__
+#define __KERNEL__
 #include 
 #include 
+#undef __KERNEL__
 #endif
 
 /*



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-tools/sb16_csp cspctl.c,1.9,1.10

2004-03-09 Thread Jaroslav Kysela
Update of /cvsroot/alsa/alsa-tools/sb16_csp
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv4377/sb16_csp

Modified Files:
cspctl.c 
Log Message:
Replaced  to 

Index: cspctl.c
===
RCS file: /cvsroot/alsa/alsa-tools/sb16_csp/cspctl.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- cspctl.c25 Mar 2003 17:35:08 -  1.9
+++ cspctl.c9 Mar 2004 12:43:22 -   1.10
@@ -30,7 +30,7 @@
 #include 
 #include 
 #include 
-#include 
+#include 
 
 /* --- commands --- */
 enum {



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-tools/sscape_ctl sscape_ctl.c,1.4,1.5

2004-03-09 Thread Jaroslav Kysela
Update of /cvsroot/alsa/alsa-tools/sscape_ctl
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv4377/sscape_ctl

Modified Files:
sscape_ctl.c 
Log Message:
Replaced  to 

Index: sscape_ctl.c
===
RCS file: /cvsroot/alsa/alsa-tools/sscape_ctl/sscape_ctl.c,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- sscape_ctl.c12 Oct 2003 08:45:32 -  1.4
+++ sscape_ctl.c9 Mar 2004 12:43:22 -   1.5
@@ -8,7 +8,7 @@
 #include 
 #include 
 
-#include 
+#include 
 #include 
 
 



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-tools/hdsploader hdsploader.c,1.7,1.8

2004-03-09 Thread Jaroslav Kysela
Update of /cvsroot/alsa/alsa-tools/hdsploader
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv4377/hdsploader

Modified Files:
hdsploader.c 
Log Message:
Replaced  to 

Index: hdsploader.c
===
RCS file: /cvsroot/alsa/alsa-tools/hdsploader/hdsploader.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- hdsploader.c26 Nov 2003 17:13:02 -  1.7
+++ hdsploader.c9 Mar 2004 12:43:21 -   1.8
@@ -23,7 +23,7 @@
 #include 
 #include 
 #include 
-#include 
+#include 
 
 static u_int32_t code[24413];
 



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-tools/seq/sbiload sbiload.c,1.9,1.10

2004-03-09 Thread Jaroslav Kysela
Update of /cvsroot/alsa/alsa-tools/seq/sbiload
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv4377/seq/sbiload

Modified Files:
sbiload.c 
Log Message:
Replaced  to 

Index: sbiload.c
===
RCS file: /cvsroot/alsa/alsa-tools/seq/sbiload/sbiload.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- sbiload.c   30 Jul 2003 14:14:21 -  1.9
+++ sbiload.c   9 Mar 2004 12:43:22 -   1.10
@@ -20,7 +20,7 @@
 
 #include 
 #include 
-#include 
+#include 
 #include 
 #include 
 #include 



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-driver INSTALL,1.160,1.161

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-driver
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv26871

Modified Files:
INSTALL 
Log Message:
moved au88x0 drivers to alsa-kernel.



Index: INSTALL
===
RCS file: /cvsroot/alsa/alsa-driver/INSTALL,v
retrieving revision 1.160
retrieving revision 1.161
diff -u -r1.160 -r1.161
--- INSTALL 2 Mar 2004 16:52:20 -   1.160
+++ INSTALL 9 Mar 2004 11:58:30 -   1.161
@@ -224,32 +224,6 @@
 Note: you need to load the firmware via usx2yloader utility included
   in alsa-tools and alsa-firmware packages.
 
-  Module snd-au8810, snd-au8820, snd-au8830
-  -
-
-Module for Aureal Vortex, Vortex2 and Advantage device.
-
-pcifix - Control PCI workarounds
- 0 = Disable all workarounds
- 1 = Force the PCI latency of the Aureal card to 0xff
- 2 = Force the Extend PCI#2 Internal Master for Efficient
- Handling of Dummy Requests on the VIA KT133 AGP Bridge
- 3 = Force both settings
- 255 = Autodetect what is required (default)
-
-This module supports all ADB PCM channels, ac97 mixer, SPDIF, hardware
-EQ, mpu401, gameport. A3D and wavetable support are still in development.
-Development and reverse engineering work is being coordinated at
-http://savannah.nongnu.org/projects/openvortex/
-SPDIF output has a copy of the AC97 codec output, unless you use the
-"spdif" pcm device, which allows raw data passthru.
-The hardware EQ hardware and SPDIF is only present in the Vortex2 and 
-Advantage.
-
-Note: Some ALSA mixer applicactions don't handle the SPDIF samplerate 
-   control correctly. If you have problems regarding this, try
-   another ALSA compliant mixer (alsamixer works).
-
   Module snd-hdspm
   
 



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-driver/pci/au88x0 Makefile,1.3,1.4 au8810.c,1.1,1.2 au8820.c,1.1,1.2 au8830.c,1.1,1.2 au8810.h,1.1,NONE au8810_core.c,1.2,NONE au8810_eq.c,1.2,NONE au8810_game.c,1.2,NONE au8810_mixer.c,1.2,NONE au8810_mpu401.c,1.2,NONE au8810_pcm.c,1.2,NONE au8820.h,1.1,NONE au8820_core.c,1.2,NONE au8820_game.c,1.2,NONE au8820_mixer.c,1.2,NONE au8820_mpu401.c,1.2,NONE au8820_pcm.c,1.2,NONE au8820_synth.c,1.2,NONE au8830.h,1.1,NONE au8830_core.c,1.2,NONE au8830_eq.c,1.2,NONE au8830_game.c,1.2,NONE au8830_mixer.c,1.2,NONE au8830_mpu401.c,1.2,NONE au8830_pcm.c,1.2,NONE au8830_synth.c,1.2,NONE au88x0.c,1.9,NONE au88x0.h,1.5,NONE au88x0_core.c,1.3,NONE au88x0_eq.c,1.1,NONE au88x0_eq.h,1.1,NONE au88x0_eqdata.c,1.1,NONE au88x0_game.c,1.2,NONE au88x0_mixer.c,1.2,NONE au88x0_mpu401.c,1.1,NONE au88x0_pcm.c,1.3,NONE au88x0_synth.c,1.1,NONE migrate,1.1,NONE

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-driver/pci/au88x0
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv26871/pci/au88x0

Modified Files:
Makefile au8810.c au8820.c au8830.c 
Removed Files:
au8810.h au8810_core.c au8810_eq.c au8810_game.c 
au8810_mixer.c au8810_mpu401.c au8810_pcm.c au8820.h 
au8820_core.c au8820_game.c au8820_mixer.c au8820_mpu401.c 
au8820_pcm.c au8820_synth.c au8830.h au8830_core.c au8830_eq.c 
au8830_game.c au8830_mixer.c au8830_mpu401.c au8830_pcm.c 
au8830_synth.c au88x0.c au88x0.h au88x0_core.c au88x0_eq.c 
au88x0_eq.h au88x0_eqdata.c au88x0_game.c au88x0_mixer.c 
au88x0_mpu401.c au88x0_pcm.c au88x0_synth.c migrate 
Log Message:
moved au88x0 drivers to alsa-kernel.



Index: Makefile
===
RCS file: /cvsroot/alsa/alsa-driver/pci/au88x0/Makefile,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- Makefile11 Nov 2003 13:12:25 -  1.3
+++ Makefile9 Mar 2004 11:58:32 -   1.4
@@ -5,12 +5,6 @@
 include $(SND_TOPDIR)/toplevel.config
 include $(SND_TOPDIR)/Makefile.conf
 
-snd-au8810-objs := au8810.o au8810_core.o au8810_pcm.o au8810_mixer.o au8810_mpu401.o 
au8810_game.o au8810_eq.o
-snd-au8820-objs := au8820.o au8820_core.o au8820_pcm.o au8820_mixer.o au8820_mpu401.o 
au8820_game.o au8820_synth.o
-snd-au8830-objs := au8830.o au8830_core.o au8830_pcm.o au8830_mixer.o au8830_mpu401.o 
au8830_game.o au8830_eq.o au8830_synth.o
-
-obj-$(CONFIG_SND_AU8810) += snd-au8810.o
-obj-$(CONFIG_SND_AU8820) += snd-au8820.o
-obj-$(CONFIG_SND_AU8830) += snd-au8830.o
+include $(SND_TOPDIR)/alsa-kernel/pci/au88x0/Makefile
 
 include $(SND_TOPDIR)/Rules.make

Index: au8810.c
===
RCS file: /cvsroot/alsa/alsa-driver/pci/au88x0/au8810.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- au8810.c6 Oct 2003 14:01:02 -   1.1
+++ au8810.c9 Mar 2004 11:58:32 -   1.2
@@ -1,8 +1,2 @@
-#include "au8810.h"
-#include "au88x0.h"
-static struct pci_device_id snd_vortex_ids[] = {
-{PCI_VENDOR_ID_AUREAL, PCI_DEVICE_ID_AUREAL_ADVANTAGE,
- PCI_ANY_ID, PCI_ANY_ID, 0, 0, 1,},
-{0,}
-};
-#include "au88x0.c"
+#include "../../alsa-kernel/pci/au88x0/au8810.c"
+EXPORT_NO_SYMBOLS;

Index: au8820.c
===
RCS file: /cvsroot/alsa/alsa-driver/pci/au88x0/au8820.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- au8820.c6 Oct 2003 14:01:03 -   1.1
+++ au8820.c9 Mar 2004 11:58:32 -   1.2
@@ -1,8 +1,2 @@
-#include "au8820.h"
-#include "au88x0.h"
-static struct pci_device_id snd_vortex_ids[] = {
-{PCI_VENDOR_ID_AUREAL, PCI_DEVICE_ID_AUREAL_VORTEX,
- PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0,},
-{0,}
-};
-#include "au88x0.c"
+#include "../../alsa-kernel/pci/au88x0/au8820.c"
+EXPORT_NO_SYMBOLS;

Index: au8830.c
===
RCS file: /cvsroot/alsa/alsa-driver/pci/au88x0/au8830.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- au8830.c6 Oct 2003 14:01:03 -   1.1
+++ au8830.c9 Mar 2004 11:58:32 -   1.2
@@ -1,8 +1,2 @@
-#include "au8830.h"
-#include "au88x0.h"
-static struct pci_device_id snd_vortex_ids[] = {
-{PCI_VENDOR_ID_AUREAL, PCI_DEVICE_ID_AUREAL_VORTEX2,
- PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0,},
-{0,}
-};
-#include "au88x0.c"
+#include "../../alsa-kernel/pci/au88x0/au8830.c"
+EXPORT_NO_SYMBOLS;

--- au8810.h DELETED ---

--- au8810_core.c DELETED ---

--- au8810_eq.c DELETED ---

--- au8810_game.c DELETED ---

--- au8810_mixer.c DELETED ---

--- au8810_mpu401.c DELETED ---

--- au8810_pcm.c DELETED ---

--- au8820.h DELETED ---

--- au8820_core.c DELETED ---

--- au8820_game.c DELETED ---

--- au8820_mixer.c DELETED ---

--- au8820_mpu401.c DELETED ---

--- au8820_pcm.c DELETED ---

--- au8820_synth.c DELETED ---

--- au8830.h DELETED ---

--- au8830_core.c DELETED ---

--- au8830_eq.c DELETED ---

--- au8830_game.c DELETED ---

--- au8830_mixer.c DELETED ---

--- au8830_mpu401.c DELETED ---

--- au8830_pcm.c DELETED ---

--- au8830_synth.c DELETED ---

--- au88x0.c DELETED ---

--- au88x0.h DELETED ---

--- au88x0_core.c DELETED ---

--- au88x0_eq.c DELETED ---

--- au88x0_eq.h DELETED ---

--- au88x0_eqdata.c DELETED ---

--- au88x0_game.c DELETED ---

--- au88x0_mixer.c DELETED ---

--- au88x0_mpu401.c DELETED ---

--- au88x0_pcm.c DELETED ---

--- au88x0_synth.c DELETED ---

--- migrate DELETED ---



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___

[alsa-cvslog] CVS: alsa-driver/pci Kconfig,1.13,1.14 Makefile,1.20,1.21

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-driver/pci
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv26871/pci

Modified Files:
Kconfig Makefile 
Log Message:
moved au88x0 drivers to alsa-kernel.



Index: Kconfig
===
RCS file: /cvsroot/alsa/alsa-driver/pci/Kconfig,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -r1.13 -r1.14
--- Kconfig 3 Mar 2004 11:51:30 -   1.13
+++ Kconfig 9 Mar 2004 11:58:32 -   1.14
@@ -6,30 +6,6 @@
  Say 'Y' or 'M' to include support for Sek'D/Marian Prodif Plus
   soundcard.
 
-config SND_AU8810
-tristate "Aureal Advantage"
-depends on SND
-   select SND_MPU401_UART
-   select SND_AC97_CODEC
-help
-  Say 'Y' or 'M' to include support for Aureal Advantage soundcards.
- 
-config SND_AU8820
-tristate "Aureal Vortex"
-depends on SND
-   select SND_MPU401_UART
-   select SND_AC97_CODEC
-help
-  Say 'Y' or 'M' to include support for Aureal Vortex soundcards.
- 
-config SND_AU8830
-tristate "Aureal Vortex 2"
-depends on SND
-   select SND_MPU401_UART
-   select SND_AC97_CODEC
-help
-  Say 'Y' or 'M' to include support for Aureal Vortex 2 soundcards.
- 
 config SND_INTEL8X0M
tristate "Intel i8x0/MX440; AMD768/8111 modems (EXPERIMENTAL)"
depends on SND && EXPERIMENTAL

Index: Makefile
===
RCS file: /cvsroot/alsa/alsa-driver/pci/Makefile,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -r1.20 -r1.21
--- Makefile6 Mar 2004 16:59:09 -   1.20
+++ Makefile9 Mar 2004 11:58:32 -   1.21
@@ -11,7 +11,7 @@
 
 clean-files := cs4281.c es1968.c intel8x0.c maestro3.c
 
-obj-$(CONFIG_SND) += pdplus/ mixart/ au88x0/
+obj-$(CONFIG_SND) += pdplus/
 
 snd-intel8x0m-objs := intel8x0m.o
 snd-hdspm-objs := hdspm.o



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-kernel/Documentation ALSA-Configuration.txt,1.32,1.33

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-kernel/Documentation
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv25457/Documentation

Modified Files:
ALSA-Configuration.txt 
Log Message:
added the au88x0 drivers for Aureal soundcards by Manuel Jander <[EMAIL PROTECTED]>


Index: ALSA-Configuration.txt
===
RCS file: /cvsroot/alsa/alsa-kernel/Documentation/ALSA-Configuration.txt,v
retrieving revision 1.32
retrieving revision 1.33
diff -u -r1.32 -r1.33
--- ALSA-Configuration.txt  23 Feb 2004 19:10:22 -  1.32
+++ ALSA-Configuration.txt  9 Mar 2004 11:52:13 -   1.33
@@ -112,7 +112,8 @@
- value is used for /proc/asound filesystem
- this value can be used by applications for identification
  of card if user does not want identify card with index number
-enable - enable card (only first card is enabled by default)
+enable - enable card.  (all cards enabled for PCI and ISA PnP cards
+ as default.)
 
   Module snd-ad1816a
   --
@@ -178,6 +179,32 @@
 
 Module supports up to 8 cards, autoprobe and PnP.
 
+  Module snd-au8810, snd-au8820, snd-au8830
+  -
+
+Module for Aureal Vortex, Vortex2 and Advantage device.
+
+pcifix - Control PCI workarounds
+ 0 = Disable all workarounds
+ 1 = Force the PCI latency of the Aureal card to 0xff
+ 2 = Force the Extend PCI#2 Internal Master for Efficient
+ Handling of Dummy Requests on the VIA KT133 AGP Bridge
+ 3 = Force both settings
+ 255 = Autodetect what is required (default)
+
+This module supports all ADB PCM channels, ac97 mixer, SPDIF, hardware
+EQ, mpu401, gameport. A3D and wavetable support are still in development.
+Development and reverse engineering work is being coordinated at
+http://savannah.nongnu.org/projects/openvortex/
+SPDIF output has a copy of the AC97 codec output, unless you use the
+"spdif" pcm device, which allows raw data passthru.
+The hardware EQ hardware and SPDIF is only present in the Vortex2 and 
+Advantage.
+
+Note: Some ALSA mixer applicactions don't handle the SPDIF samplerate 
+   control correctly. If you have problems regarding this, try
+   another ALSA compliant mixer (alsamixer works).
+
   Module snd-azt2320
   --
 
@@ -608,6 +635,7 @@
  1 = use headphone control as master
  2 = swap headphone and master controls
  3 = for AD1985, turn on OMS bit and use headphone
+ 4 = for ALC65x, turn on the jack sense mode
 
 Module supports autoprobe and multiple bus-master chips (max 8).
 



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-kernel/pci Kconfig,1.22,1.23 Makefile,1.13,1.14

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-kernel/pci
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv25457/pci

Modified Files:
Kconfig Makefile 
Log Message:
added the au88x0 drivers for Aureal soundcards by Manuel Jander <[EMAIL PROTECTED]>


Index: Kconfig
===
RCS file: /cvsroot/alsa/alsa-kernel/pci/Kconfig,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -r1.22 -r1.23
--- Kconfig 3 Mar 2004 11:50:34 -   1.22
+++ Kconfig 9 Mar 2004 11:52:13 -   1.23
@@ -15,6 +15,30 @@
help
  Say 'Y' or 'M' to include support for ALI PCI Audio M5451 sound core.
 
+config SND_AU8810
+tristate "Aureal Advantage"
+depends on SND
+   select SND_MPU401_UART
+   select SND_AC97_CODEC
+help
+  Say 'Y' or 'M' to include support for Aureal Advantage soundcards.
+ 
+config SND_AU8820
+tristate "Aureal Vortex"
+depends on SND
+   select SND_MPU401_UART
+   select SND_AC97_CODEC
+help
+  Say 'Y' or 'M' to include support for Aureal Vortex soundcards.
+ 
+config SND_AU8830
+tristate "Aureal Vortex 2"
+depends on SND
+   select SND_MPU401_UART
+   select SND_AC97_CODEC
+help
+  Say 'Y' or 'M' to include support for Aureal Vortex 2 soundcards.
+ 
 config SND_AZT3328
tristate "Aztech AZF3328 / PCI168 (EXPERIMENTAL)"
depends on SND && EXPERIMENTAL

Index: Makefile
===
RCS file: /cvsroot/alsa/alsa-kernel/pci/Makefile,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -r1.13 -r1.14
--- Makefile9 Feb 2004 17:40:48 -   1.13
+++ Makefile9 Mar 2004 11:52:13 -   1.14
@@ -41,6 +41,7 @@
 obj-$(CONFIG_SND) += \
ac97/ \
ali5451/ \
+   au88x0/ \
cs46xx/ \
emu10k1/ \
ice1712/ \



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-kernel/pci/au88x0 - New directory

2004-03-09 Thread Takashi Iwai
Update of /cvsroot/alsa/alsa-kernel/pci/au88x0
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv24802/pci/au88x0

Log Message:
Directory /cvsroot/alsa/alsa-kernel/pci/au88x0 added to the repository




---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog
Index: tumbler.c
===
RCS file: /cvsroot/alsa/alsa-kernel/ppc/tumbler.c,v
retrieving revision 1.27
retrieving revision 1.28
diff -u -r1.27 -r1.28
--- tumbler.c   4 Mar 2004 17:53:06 -   1.27
+++ tumbler.c   9 Mar 2004 13:21:44 -   1.28
@@ -94,6 +94,7 @@
unsigned int mix_vol[VOL_IDX_LAST_MIX][2]; /* stereo volumes for tas3004 */
int drc_range;
int drc_enable;
+   int capture_source;
 } pmac_tumbler_t;
 
 
@@ -135,8 +136,8 @@
TAS_REG_MCS, (1<<6)|(2<<4)|0,
/* normal operation, all-pass mode */
TAS_REG_MCS2, (1<<1),
-   /* normal output, no deemphasis, A input, power-up */
-   TAS_REG_ACS, 2,
+   /* normal output, no deemphasis, A input, power-up, line-in */
+   TAS_REG_ACS, 0,
0, /* terminator */
};
return send_init_client(i2c, regs);
@@ -681,6 +682,52 @@
return 0;
 }
 
+static int snapper_set_capture_source(pmac_tumbler_t *mix)
+{
+   return snd_pmac_keywest_write_byte(&mix->i2c, TAS_REG_ACS,
+  mix->capture_source ? 2 : 0);
+}
+
+static int snapper_info_capture_source(snd_kcontrol_t *kcontrol, snd_ctl_elem_info_t 
*uinfo)
+{
+   static char *texts[2] = {
+   "Line", "Mic"
+   };
+   uinfo->type = SNDRV_CTL_ELEM_TYPE_ENUMERATED;
+   uinfo->count = 1;
+   uinfo->value.integer.min = 0;
+   uinfo->value.integer.max = 1;
+   if (uinfo->value.enumerated.item > 1)
+   uinfo->value.enumerated.item = 1;
+   strcpy(uinfo->value.enumerated.name, texts[uinfo->value.enumerated.item]);
+   return 0;
+}
+
+static int snapper_get_capture_source(snd_kcontrol_t *kcontrol, snd_ctl_elem_value_t 
*ucontrol)
+{
+   pmac_t *chip = snd_kcontrol_chip(kcontrol);
+   pmac_tumbler_t *mix = chip->mixer_data;
+
+   snd_assert(mix, return -ENODEV);
+   ucontrol->value.integer.value[0] = mix->capture_source;
+   return 0;
+}
+
+static int snapper_put_capture_source(snd_kcontrol_t *kcontrol, snd_ctl_elem_value_t 
*ucontrol)
+{
+   pmac_t *chip = snd_kcontrol_chip(kcontrol);
+   pmac_tumbler_t *mix = chip->mixer_data;
+   int change;
+
+   snd_assert(mix, return -ENODEV);
+   change = ucontrol->value.integer.value[0] != mix->capture_source;
+   if (change) {
+   mix->capture_source = !!ucontrol->value.integer.value[0];
+   snapper_set_capture_source(mix);
+   }
+   return change;
+}
+
 #define DEFINE_SNAPPER_MIX(xname,idx,ofs) { \
.iface = SNDRV_CTL_ELEM_IFACE_MIXER,\
.name = xname, \
@@ -754,6 +801,12 @@
  .get = tumbler_get_drc_value,
  .put = tumbler_put_drc_value
},
+   { .iface = SNDRV_CTL_ELEM_IFACE_MIXER,
+ .name = "Input Source", /* FIXME: "Capture Source" doesn't work properly */
+ .info = snapper_info_capture_source,
+ .get = snapper_get_capture_source,
+ .put = snapper_put_capture_source
+   },
 };
 
 static snd_kcontrol_new_t tumbler_hp_sw __initdata = {
@@ -932,6 +985,7 @@
tumbler_set_mono_volume(mix, &snapper_bass_vol_info);
tumbler_set_mono_volume(mix, &snapper_treble_vol_info);
snapper_set_drc(mix);
+   snapper_set_capture_source(mix);
}
tumbler_set_master_volume(mix);
if (chip->update_automute)



---
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click
___
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog


[alsa-cvslog] CVS: alsa-utils/aplay aplay.c,1.176,1.177

2004-03-09 Thread Jaroslav Kysela
Update of /cvsroot/alsa/alsa-utils/aplay
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv11271

Modified Files:
aplay.c 
Log Message:
more 64-bit stuff
